paired_ingress_side

Function paired_ingress_side 

fn paired_ingress_side(side: ProxySide) -> ProxySide
The ingress side of the other direction of the same stream.

A bidirectional stream is forwarded by two pipes, and the second one carries bytes the other way. ClientToProxy and RelayToProxy are the two ingress sides; this is the turn between them.