fn classify_object(kind: ActionKind, cx: &CapCtx) -> SupportExpand description
The object site, on a stream the framer can address: subgroup streams on every compiled draft, and fetch streams on the drafts whose objects this codec can read.
fn classify_object(kind: ActionKind, cx: &CapCtx) -> SupportThe object site, on a stream the framer can address: subgroup streams on every compiled draft, and fetch streams on the drafts whose objects this codec can read.